/* -*- mode: c++ -*- */

/** @file

hippodraw::ListDialog class interface

Copyright (C) 2004-2006   The Board of Trustees of The Leland Stanford
Junior University.  All Rights Reserved.

$Id: ListDialog.h,v 1.10 2006/04/25 18:30:46 pfkeb Exp $

*/

#ifndef _ListDialog_H_
#define _ListDialog_H_

// #include <qglobal.h> // for version
// #if QT_VERSION < 0x040000
#include "qtui/ListDialogBase.h"
// #else
// #include "ListDialogUI.h"
// #endif

#include <string>
#include <vector>

namespace hippodraw {

/** A derived class of ListDialogBase class which is generated by the
    Qt designer.  It provides dialog which presents the names of the
    top level DataSource objects in the file that can be used.  The
    user can then select one.

    Examples of files that can have multiple DataSource objects are
    ROOT and FITS files.

    @todo Write a FileIconProvider so that QFileDialog can highlight
    known file types.

    @author Paul F. Kunz <Paul_Kunz@slac.stanford.edu>

*/
// #if QT_VERSION < 0x040000
class ListDialog : public ListDialogBase
// #else
// class ListDialog : public QDialog,
// 		   private Ui::ListDialogUI
// #endif
{
private:

  /** The list of items added to the list of data source names.
   */
#if QT_VERSION < 0x040000
  std::vector < QListViewItem * > m_item_list;
#else
  std::vector < Q3ListViewItem * > m_item_list;
#endif

public:

  /** The constructor. The constructor using @a parent as its parent
      widget.
   */
  ListDialog ( QWidget * parent );

  /** Sets the names of the of the top level objects that might be
      valid DataSource objects.
   */
  void setNames ( const std::vector < std::string > & names );

  /** Returns the index of the selected item.
   */
  unsigned int selectedItem () const;

  /** Responds to a double click on the contained QListView object.
      Responds to a double click on the contained QListView object by
      issuing QDialog::done with return code the index of selected
      QListViewItem.
  */
  virtual void doubleClicked ();

};

} // namespace hippodraw

#endif // _ListDialog_H_
