/* -*- mode: c++ -*- */

/** @file

hippodraw::PickTable class interface

Copyright (C) 2003-2006   The Board of Trustees of The Leland Stanford
Junior University.  All Rights Reserved.

$Id: PickTable.h,v 1.55 2006/11/21 23:37:12 xiefang Exp $

*/

#ifndef _PickTable_H_
#define _PickTable_H_

#include <qglobal.h>
#include "qtui/PickTableBase.h"

#if QT_VERSION < 0x040000
#else
#include "libqthippo.h"
class Q3ListViewItem;
#endif

#include <vector>

namespace hippodraw {

class NTuple;
class NTupleSorter;
class PlotterBase;
class DataRep;

/** A derived class of PickTableBase class which is generated by the
    Qt designer.  It provides an PickTable which lists points selected by
    the user.

    @bug When entering a new entry, density should be calculated 
    from entries/bin.

    @author Paul F. Kunz <Paul_Kunz@slac.stanford.edu>
    @author Sanket B Malde <sanket@stanford.edu>
*/
// #if QT_VERSION < 0x040000
class MDL_QTHIPPOPLOT_API PickTable : public PickTableBase
// #else
// class MDL_QTHIPPOPLOT_API PickTable : public QDialog,
// 				      private Ui::PickTableUI
// #endif
{

private:

  /** The object that maintains the NTuple of picked data points.
   */
  NTupleSorter * m_sorter;

  /** The target PlotterBase object. The target PlotterBase object
      upon which one is picking.
   */
  PlotterBase * m_target;

  /** The number of columns of the pick table.
   */
  unsigned int m_column;

  /** The DataRep of picked points. */
  DataRep * m_datarep;

protected:

  /** Responds to @b addEntry button.
   */
  virtual void addEntry();

  /** Responds to the 'clear' button click. Clears the list of picked
      points. */
  virtual void clear();

  /** Responds to the 'Delete Selected Item' button click. Deletes the
      selected point. */
  virtual void deleteSelectedItem();

  /** Responds to the 'Show picked points' check box click.
   */
  virtual void pickedCheckBoxClicked();

  /** Sorts the table.
   */
  virtual void listSorted ( int );

  /** Finds the index of the @a target QListViewItem. 
   */
#if QT_VERSION < 0x040000
  unsigned int indexOf ( QListViewItem * target );
#else
  unsigned int indexOf ( Q3ListViewItem * target );
#endif

  /** Refreshes the view of all the items.  Refreshes the view of the
      picked items.  Sets the @a select item to be selected and
      scrolled so it is visible. If @a select is greater or equal to
      the number of rows, then no item will be selected.
   */
  void refreshItems ( unsigned int select);

  /** Add DataRep object, called by constructor or show picked points
      check box.  Used to respond to 'Add Datarep' button.
   */
  void addDataRep ();

public:

  /** A constructor.  A constructor taking the PlotterBase object as
      argument.  The @a plotter is the one from which one is picking.
   */
  PickTable ( PlotterBase * plotter );

  /** Adds a new point to the pick NTuple and the PickTable's
      window. 
  */
  void addItem ( std::vector < double > & v );

  /** Responds to change of selection in the QListView.
   */
  virtual void m_pick_table_selectionChanged();

  /** Gets the pick table as a NTuple.
   */
  NTuple * getPickTable () const;

};

} // namespace hippodraw

#endif // _PickTable_H_
