/* -*- mode: c++ -*- */

/** @file

hippodaraw::QtSortedCheckListItem class interface.

 This class inherits the QCheckListItem class and overrides the
compare() function. It is used to sort the QListView in numerical
order.

Copyright (C) 2006   The Board of Trustees of The Leland Stanford Junior
University.  All Rights Reserved.

$Id: QtSortedCheckListItem.h,v 1.2 2006/02/13 01:23:57 pfkeb Exp $

*/

#ifndef _QtSorted_H_
#define _QtSorted_H_

#include <qglobal.h> // for version
#if QT_VERSION < 0x040000
#include "qlistview.h"
#else
#include "q3listview.h"
#endif

namespace hippodraw {


/** This class inherits the QCheckListItem and overrides the compare() 
    function, so that the list can be sorted in numerical order.

    @author Xie Fang <xiefang@stanford.edu>
*/

#if QT_VERSION < 0x040000
class QtSortedCheckListItem : public QCheckListItem
#else
class QtSortedCheckListItem : public Q3CheckListItem
#endif
{

public:

#if QT_VERSION < 0x040000
  typedef QCheckListItem::Type Type;
  QtSortedCheckListItem ( QListView * parent, const QString & text );
  virtual int compare ( QListViewItem *i, int col, bool ascending ) const;
#else
  typedef Q3CheckListItem::Type Type;
  QtSortedCheckListItem ( Q3ListView * parent, const QString & text );
  virtual int compare ( Q3ListViewItem *i, int col, bool ascending ) const;
#endif

};

} // namespace hippodraw
#endif //_QtSorted_H_

