/*-*- c++ -*-******************************************************************
 * Qwt Widget Library 
 * Copyright (C) 1997   Josef Wilgen
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *****************************************************************************/

#ifndef QWT_PAINT_BUFFER_H
#define QWT_PAINT_BUFFER_H 1

#include <qpixmap.h>
//#include "qwt_global.h"

class QPainter;

namespace hippodraw {

/*!
  \brief Paint buffer for Qwt widgets

  QwtPaintBuffer offers a simple way to en/disable double buffering.
  Double buffering is enabled as default and in general there will be
  no reason to change this. 
*/

class QwtPaintBuffer
{
public:
    QwtPaintBuffer();
    QwtPaintBuffer(QPaintDevice *, const QRect &, QPainter *painter = NULL);

    virtual ~QwtPaintBuffer();

    void open(QPaintDevice *, const QRect &, QPainter *painter = NULL);
    void close();

    QPainter *painter();
    const QPaintDevice *device();
    
    static void setEnabled(bool enable);
    static bool isEnabled();

protected:
    void flush();

private:
    QPixmap d_pixBuffer;
    QRect d_rect;

    QPaintDevice *d_device; // use QGuardedPtr
    QPainter *d_painter; // use QGuardedPtr
    QPainter *d_devicePainter; // use QGuardedPtr

    static bool d_enabled;
};

} // namespace hippodraw

#endif
