/* -*- mode: c++ -*- */

/** @file

hippodraw::HammerAito2 class interface

Copyright (C) 2002-2004, 2006   The Board of Trustees of The Leland
Stanford Junior University.  All Rights Reserved.

The library is distributed under the terms of the GNU Lesser General
Public License.

$Id: HammerAito2.h,v 1.1 2007/03/14 23:28:29 xiefang Exp $

*/

#ifndef _HammerAito2_H_
#define _HammerAito2_H_

#include "PeriodicBinaryTransform.h"


namespace hippodraw {

/** A transform that performs the HammerAito projection.  A transform
    that performs the Hammer-Aitoff map projection. This map
    projection is an equal-area projection which displays the world on
    an ellipse. "Equal-area" means equal-areas on the globe are equal
    areas on the two dimension projection. If this transforms were
    used with an XY Plot containing the boundaries of the continents,
    it might look like image below.

    @bug @@@@@@ The projection near the poles has incorrect white
    space. ( To remove: color box size changed when transformation applied )

    @bug @@@@ The right hand side of the axis box is not drawn. ( To
    remove: probably not a bug, since -180 and +180 is the same edge
    and should not be drawn twice. )

    @image html hammer.gif A Hammer-Aitoff projection.
    @image latex hammer.eps A Hammer-Aitoff projection
*/
class MDL_HIPPOPLOT_API HammerAito2 : public PeriodicBinaryTransform
{

private:

  
public:

  /** The constructor. The constructor taking a UnaryTransform for its
      Z axis.  */
  HammerAito2 ( UnaryTransform * z );

  /** The copy constructor. */
  HammerAito2 ( const HammerAito2 & );

  /** The virtual destructor. */
  virtual ~HammerAito2();

  /** Creates a new Transform object by copying an existing one. */
#ifdef CLONE_DEFECT
  virtual TransformBase * clone () const;
#else
  virtual HammerAito2    * clone () const;
#endif


  virtual double aspectRatio () const;


};

} // namespace hippodraw

#endif // _HammerAito2_H_
